==> kubernetes-model-2.0.4-sources.jar: io/fabric8/openshift/api/model/NamedRoleBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class NamedRoleBuilder extends NamedRoleFluentImpl<NamedRoleBuilder> implements VisitableBuilder<NamedRole,NamedRoleBuilder>{

    NamedRoleFluent<?> fluent;
    Boolean validationEnabled;

    public NamedRoleBuilder(){
            this(true);
    }
    public NamedRoleBuilder(Boolean validationEnabled){
            this(new NamedRole(), validationEnabled);
    }
    public NamedRoleBuilder(NamedRoleFluent<?> fluent){
            this(fluent, true);
    }
    public NamedRoleBuilder(NamedRoleFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new NamedRole(), validationEnabled);
    }
    public NamedRoleBuilder(NamedRoleFluent<?> fluent,NamedRole instance){
            this(fluent, instance, true);
    }
    public NamedRoleBuilder(NamedRoleFluent<?> fluent,NamedRole instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withName(instance.getName()); 
            fluent.withRole(instance.getRole()); 
            this.validationEnabled = validationEnabled; 
    }
    public NamedRoleBuilder(NamedRole instance){
            this(instance,true);
    }
    public NamedRoleBuilder(NamedRole instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withName(instance.getName()); 
            this.withRole(instance.getRole()); 
            this.validationEnabled = validationEnabled; 
    }

    public NamedRole build(){
            NamedRole buildable = new NamedRole(fluent.getName(),fluent.getRole());
            io.fabric8.kubernetes.api.builder.ValidationUtils.validate(buildable);
            return buildable;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            NamedRoleBuilder that = (NamedRoleBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}

==> kubernetes-model-4.1.0-sources.jar: io/fabric8/openshift/api/model/NamedRoleBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
import javax.validation.Validator;

public class NamedRoleBuilder extends NamedRoleFluentImpl<NamedRoleBuilder> implements VisitableBuilder<NamedRole,NamedRoleBuilder>{

    NamedRoleFluent<?> fluent;
    Boolean validationEnabled;
    Validator validator;

    public NamedRoleBuilder(){
            this(true);
    }
    public NamedRoleBuilder(Boolean validationEnabled){
            this(new NamedRole(), validationEnabled);
    }
    public NamedRoleBuilder(NamedRoleFluent<?> fluent){
            this(fluent, true);
    }
    public NamedRoleBuilder(NamedRoleFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new NamedRole(), validationEnabled);
    }
    public NamedRoleBuilder(NamedRoleFluent<?> fluent,NamedRole instance){
            this(fluent, instance, true);
    }
    public NamedRoleBuilder(NamedRoleFluent<?> fluent,NamedRole instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withName(instance.getName()); 
            fluent.withRole(instance.getRole()); 
            this.validationEnabled = validationEnabled; 
    }
    public NamedRoleBuilder(NamedRole instance){
            this(instance,true);
    }
    public NamedRoleBuilder(NamedRole instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withName(instance.getName()); 
            this.withRole(instance.getRole()); 
            this.validationEnabled = validationEnabled; 
    }
    public NamedRoleBuilder(Validator validator){
            this(new NamedRole(), true);
    }
    public NamedRoleBuilder(NamedRoleFluent<?> fluent,NamedRole instance,Validator validator){
            this.fluent = fluent; 
            fluent.withName(instance.getName()); 
            fluent.withRole(instance.getRole()); 
            this.validator = validator;
            this.validationEnabled = validator != null; 
    }
    public NamedRoleBuilder(NamedRole instance,Validator validator){
            this.fluent = this; 
            this.withName(instance.getName()); 
            this.withRole(instance.getRole()); 
            this.validator = validator; 
            this.validationEnabled = validator != null; 
    }

    public NamedRole build(){
            NamedRole buildable = new NamedRole(fluent.getName(),fluent.getRole());
            if (validationEnabled) {io.fabric8.kubernetes.api.builder.ValidationUtils.validate(buildable, validator);}
            return buildable;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            NamedRoleBuilder that = (NamedRoleBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}
